from django.conf import settings
from django.urls import re_path, path, include

from . views import *


# CMS_PATH_PREFIX = getattr(settings, 'CMS_PATH_PREFIX', '')
_board_base = 'editorial-board'

urlpatterns = []

urlpatterns += [
    path(f'{_board_base}/', board_base, name='board_base'),
]



# from django.contrib.admin.views.decorators import staff_member_required
from django.contrib.auth.decorators import login_required
from django.core.exceptions import PermissionDenied
from django.shortcuts import render


# @staff_member_required
@login_required
def board_base(request):
    if not request.user.is_staff:
        raise PermissionDenied
    template = "board.html"
    return render(request, template)
